## NGBS iCON Python API

This is an **async Python client library** for communicating with **NGBS iCON** controllers. It allows querying and controlling zones, retrieving sensor and controller data, and issuing commands over the native socket-based protocol.

It is intended for use in Home Assistant.

> This project is a rework of [molnarg/ngbs-icon](https://github.com/molnarg/ngbs-icon), adapted for use with Python.